/* _dict.cc 25/03/1999 20.11.10 */
/* inittab.cc 28/08/2000 18.12.46 */
PUBLIC MODULE_inittab::MODULE_inittab (void);
PUBLIC void MODULE_inittab::setmenu (DIALOG&dia, MENU_CONTEXT context);
PUBLIC int MODULE_inittab::domenu (MENU_CONTEXT context,
	 const char *key);
PUBLIC void MODULE_inittab::usage (SSTRINGS&tb);
PUBLIC int MODULE_inittab::execmain (int argc, char *argv[], bool);
/* inittabedit.cc 25/03/1999 22.21.50 */
PRIVATE void INITTAB_REC::init (void);
PUBLIC INITTAB_REC::INITTAB_REC (void);
PUBLIC int INITTAB_REC::parse (const char *line);
PUBLIC bool INITTAB_REC::reformat (SSTRING&line);
PUBLIC INITTAB::INITTAB (void);
PRIVATE VIEWITEM *INITTAB::locatedefaultlevel (INITTAB_REC&rec);
PUBLIC int INITTAB::setdefaultlevel (int newlevel);
PUBLIC int INITTAB::getdefaultlevel (void);
